@@ -41,11 +41,23 @@ class Stream(Generic[T]):
     def count(self) -> int:
         return len(list(self._stream))
 
-    def reduce(self, func: Callable[[T, T], T], initial: T = None) -> 'T':
+    def sum(self) -> 'T':
+        return sum(self._stream)
+
+    def group_by(self, classifier: Callable[[T], K]) -> Dict[K, List[T]]:
+        groups = {}
+        for i in self._stream:
+            groups.setdefault(classifier(i), []).append(i)
+        return groups
+
+    def reduce(self, func: Callable[[T, T], T], initial: T = None) -> Optional[T]:
         if initial:
             return reduce(func, self._stream, initial)
         else:
-            return reduce(func, self._stream)
+            try:
+                return reduce(func, self._stream)
+            except TypeError:
+                return None
 
     def limit(self, max_size: int) -> 'Stream[T]':
         return Stream(islice(self._stream, max_size))
@@ -102,4 +114,4 @@ class Stream(Generic[T]):
         return set(self._stream)
 
     def to_map(self, k: Callable[[T], K], v: Callable[[T], U]) -> Dict[K, U]:
-        return {k(i): v(i) for i in self._stream}
+        return {k(i): v(i) for i in self._stream}
\ No newline at end of file
